library(tidyverse)
library(mice)

args <- commandArgs(trailingOnly = TRUE)

df_baseline <- readRDS(args[[1]])
out_dir <- args[[2]]
m <- as.numeric(args[[3]])
maxiter <- as.numeric(args[[4]])
seed <- as.numeric(args[[5]])

mi_baseline <- df_baseline %>%
  select(-gupi) %>%
  mutate_if(is.character, factor) %>%
  mice::mice(
    m     = m,
    seed  = seed,
    maxit = maxiter
  )

# save the individual complete data sets
for (i in 1:m) {
  mice::complete(mi_baseline, action = i, include = FALSE) %>%
    mutate_if(is.factor, as.character) %>%
    as_tibble() %>%
    mutate(
      gupi = df_baseline$gupi
    ) %>%
    select(gupi, everything()) %>%
    saveRDS(file = sprintf("%s/df_baseline_mi_%i.rds", out_dir, i))
}
